package net.knarcraft.blacksmithvisuals.command;

import net.citizensnpcs.api.CitizensAPI;
import net.citizensnpcs.api.npc.NPC;
import net.knarcraft.blacksmith.trait.BlacksmithTrait;
import net.knarcraft.blacksmith.trait.ScrapperTrait;
import net.knarcraft.blacksmithvisuals.container.SoundData;
import net.knarcraft.blacksmithvisuals.util.SoundHelper;
import org.bukkit.Sound;
import org.bukkit.SoundCategory;
import org.bukkit.command.Command;
import org.bukkit.command.CommandSender;
import org.bukkit.command.TabExecutor;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.ArrayList;
import java.util.List;

/**
 * A command for testing different sounds for blacksmiths and scrappers
 */
public class PlayTestSoundCommand implements TabExecutor {

    private List<String> soundCategories = null;
    private List<String> sounds = null;

    @Override
    public boolean onCommand(@NotNull CommandSender commandSender, @NotNull Command command, @NotNull String s,
                             @NotNull String[] arguments) {
        NPC npc = CitizensAPI.getDefaultNPCSelector().getSelected(commandSender);
        if (npc == null || (!npc.hasTrait(BlacksmithTrait.class) && !npc.hasTrait(ScrapperTrait.class))) {
            commandSender.sendMessage("You must select a scrapper or blacksmith NPC before executing this command");
            return true;
        }

        if (arguments.length < 2) {
            return false;
        }

        SoundCategory soundCategory;
        Sound sound;

        try {
            soundCategory = SoundCategory.valueOf(arguments[0].toUpperCase());
            sound = Sound.valueOf(arguments[1].toUpperCase());
        } catch (IllegalArgumentException exception) {
            return false;
        }

        float volume = 1;
        float pitch = 1;

        try {
            if (arguments.length > 2) {
                volume = Float.parseFloat(arguments[2]);
            }
            if (arguments.length > 3) {
                pitch = Float.parseFloat(arguments[3]);
            }
        } catch (NumberFormatException exception) {
            return false;
        }

        SoundData soundData = new SoundData(soundCategory, sound, volume, pitch, 0, true);
        SoundHelper.playSound(npc.getEntity(), soundData);
        return true;
    }

    @Nullable
    @Override
    public List<String> onTabComplete(@NotNull CommandSender commandSender, @NotNull Command command, @NotNull String s,
                                      @NotNull String[] arguments) {
        if (arguments.length == 1) {
            if (soundCategories == null) {
                soundCategories = new ArrayList<>();
                for (SoundCategory soundCategory : SoundCategory.values()) {
                    soundCategories.add(soundCategory.name());
                }
            }
            List<String> copy = new ArrayList<>(soundCategories);
            copy.removeIf((item) -> !item.contains(arguments[0]));
            return copy;
        } else if (arguments.length == 2) {
            if (sounds == null) {
                sounds = new ArrayList<>();
                for (Sound sound : Sound.values()) {
                    sounds.add(sound.name());
                }
            }
            List<String> copy = new ArrayList<>(sounds);
            copy.removeIf((item) -> !item.contains(arguments[1]));
            return copy;
        } else if (arguments.length == 3 || arguments.length == 4) {
            return List.of("0.5", "1", "1.5");
        }
        return List.of();
    }

}
