package net.knarcraft.blacksmithvisuals.property;

import org.jetbrains.annotations.NotNull;

/**
 * An identifier for the available blacksmith/scrapper sounds
 */
public enum SoundIdentifier {

    /**
     * The sound played while a blacksmith is working
     */
    REFORGING_WORKING("blacksmith.sounds.reforgeWorking"),

    /**
     * The sound played when a blacksmith finishes successfully
     */
    REFORGING_SUCCESS("blacksmith.sounds.reforgeSuccess"),

    /**
     * The sound played when a blacksmith finishes with a failure
     */
    REFORGING_FAILURE("blacksmith.sounds.reforgeFailure"),

    /**
     * The sound played while a scrapper is working
     */
    SALVAGING_WORKING("scrapper.sounds.salvageWorking"),

    /**
     * The sound played when a scrapper finishes successfully
     */
    SALVAGING_SUCCESS("scrapper.sounds.salvageSuccess"),

    /**
     * The sound played when a scrapper finishes with a failure
     */
    SALVAGING_FAILURE("scrapper.sounds.salvageFailure"),
    ;

    private final String configNode;

    /**
     * Instantiates a new sound identifier
     *
     * @param configNode <p>The sound's configuration node</p>
     */
    SoundIdentifier(@NotNull String configNode) {
        this.configNode = configNode;
    }

    /**
     * Gets the configuration node corresponding to the sound
     *
     * @return <p>The configuration node</p>
     */
    public String getConfigNode() {
        return this.configNode;
    }

}
