package net.knarcraft.blacksmithvisuals.util;

import net.knarcraft.blacksmithvisuals.BlacksmithVisuals;
import net.knarcraft.blacksmithvisuals.container.SoundData;
import org.bukkit.Bukkit;
import org.bukkit.World;
import org.bukkit.entity.Entity;
import org.jetbrains.annotations.NotNull;

/**
 * A helper class for working with sounds
 */
public final class SoundHelper {

    private SoundHelper() {

    }

    /**
     * Plays a sound according to the given sound data
     *
     * @param entity    <p>The entity to play the sound from</p>
     * @param soundData <p>The data describing the sound to play</p>
     */
    public static void playSound(@NotNull Entity entity, @NotNull SoundData soundData) {
        // Don't play disabled sounds
        if (!soundData.enabled()) {
            return;
        }

        World world = entity.getLocation().getWorld();
        if (world == null) {
            return;
        }

        int delay = Math.max(soundData.offsetTicks(), 0);
        Bukkit.getScheduler().scheduleSyncDelayedTask(BlacksmithVisuals.getInstance(), () ->
                world.playSound(entity, soundData.sound(), soundData.soundCategory(),
                        soundData.volume(), soundData.pitch()), delay);
    }

}
